# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/attestation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/peggy/v1/attestation.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\x83\x01\n\x0b\x41ttestation\x12\x1a\n\x08observed\x18\x01 \x01(\x08R\x08observed\x12\x14\n\x05votes\x18\x02 \x03(\tR\x05votes\x12\x16\n\x06height\x18\x03 \x01(\x04R\x06height\x12*\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\x05\x63laim\"_\n\nERC20Token\x12\x1a\n\x08\x63ontract\x18\x01 \x01(\tR\x08\x63ontract\x12\x35\n\x06\x61mount\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount*\x9f\x02\n\tClaimType\x12.\n\x12\x43LAIM_TYPE_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_UNKNOWN\x12.\n\x12\x43LAIM_TYPE_DEPOSIT\x10\x01\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_DEPOSIT\x12\x30\n\x13\x43LAIM_TYPE_WITHDRAW\x10\x02\x1a\x17\x8a\x9d \x13\x43LAIM_TYPE_WITHDRAW\x12<\n\x19\x43LAIM_TYPE_ERC20_DEPLOYED\x10\x03\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_ERC20_DEPLOYED\x12<\n\x19\x43LAIM_TYPE_VALSET_UPDATED\x10\x04\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_VALSET_UPDATED\x1a\x04\x88\xa3\x1e\x00\x42\xe1\x01\n\x16\x63om.injective.peggy.v1B\x10\x41ttestationProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.attestation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\020AttestationProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_CLAIMTYPE']._loaded_options = None
  _globals['_CLAIMTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \022CLAIM_TYPE_UNKNOWN'
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_DEPOSIT"]._loaded_options = None
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_DEPOSIT"]._serialized_options = b'\212\235 \022CLAIM_TYPE_DEPOSIT'
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_WITHDRAW"]._loaded_options = None
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_WITHDRAW"]._serialized_options = b'\212\235 \023CLAIM_TYPE_WITHDRAW'
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._loaded_options = None
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_ERC20_DEPLOYED'
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._loaded_options = None
  _globals['_CLAIMTYPE'].values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_VALSET_UPDATED'
  _globals['_ERC20TOKEN'].fields_by_name['amount']._loaded_options = None
  _globals['_ERC20TOKEN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_CLAIMTYPE']._serialized_start=341
  _globals['_CLAIMTYPE']._serialized_end=628
  _globals['_ATTESTATION']._serialized_start=110
  _globals['_ATTESTATION']._serialized_end=241
  _globals['_ERC20TOKEN']._serialized_start=243
  _globals['_ERC20TOKEN']._serialized_end=338
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>ibc/applications/interchain_accounts/controller/v1/query.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x1cgoogle/api/annotations.proto\"Z\n\x1dQueryInterchainAccountRequest\x12\x14\n\x05owner\x18\x01 \x01(\tR\x05owner\x12#\n\rconnection_id\x18\x02 \x01(\tR\x0c\x63onnectionId\":\n\x1eQueryInterchainAccountResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\x14\n\x12QueryParamsRequest\"i\n\x13QueryParamsResponse\x12R\n\x06params\x18\x01 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsR\x06params2\xfc\x03\n\x05Query\x12\x9a\x02\n\x11InterchainAccount\x12Q.ibc.applications.interchain_accounts.controller.v1.QueryInterchainAccountRequest\x1aR.ibc.applications.interchain_accounts.controller.v1.QueryInterchainAccountResponse\"^\x82\xd3\xe4\x93\x02X\x12V/ibc/apps/interchain_accounts/controller/v1/owners/{owner}/connections/{connection_id}\x12\xd5\x01\n\x06Params\x12\x46.ibc.applications.interchain_accounts.controller.v1.QueryParamsRequest\x1aG.ibc.applications.interchain_accounts.controller.v1.QueryParamsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/ibc/apps/interchain_accounts/controller/v1/paramsB\xff\x02\n6com.ibc.applications.interchain_accounts.controller.v1B\nQueryProtoP\x01ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\xa2\x02\x04IAIC\xaa\x02\x31Ibc.Applications.InterchainAccounts.Controller.V1\xca\x02\x31Ibc\\Applications\\InterchainAccounts\\Controller\\V1\xe2\x02=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\xea\x02\x35Ibc::Applications::InterchainAccounts::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6com.ibc.applications.interchain_accounts.controller.v1B\nQueryProtoP\001ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\242\002\004IAIC\252\0021Ibc.Applications.InterchainAccounts.Controller.V1\312\0021Ibc\\Applications\\InterchainAccounts\\Controller\\V1\342\002=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\352\0025Ibc::Applications::InterchainAccounts::Controller::V1'
  _globals['_QUERY'].methods_by_name['InterchainAccount']._loaded_options = None
  _globals['_QUERY'].methods_by_name['InterchainAccount']._serialized_options = b'\202\323\344\223\002X\022V/ibc/apps/interchain_accounts/controller/v1/owners/{owner}/connections/{connection_id}'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\0024\0222/ibc/apps/interchain_accounts/controller/v1/params'
  _globals['_QUERYINTERCHAINACCOUNTREQUEST']._serialized_start=217
  _globals['_QUERYINTERCHAINACCOUNTREQUEST']._serialized_end=307
  _globals['_QUERYINTERCHAINACCOUNTRESPONSE']._serialized_start=309
  _globals['_QUERYINTERCHAINACCOUNTRESPONSE']._serialized_end=367
  _globals['_QUERYPARAMSREQUEST']._serialized_start=369
  _globals['_QUERYPARAMSREQUEST']._serialized_end=389
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=391
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=496
  _globals['_QUERY']._serialized_start=499
  _globals['_QUERY']._serialized_end=1007
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.injective.erc20.v1beta1 import params_pb2 as injective_dot_erc20_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.erc20.v1beta1 import genesis_pb2 as injective_dot_erc20_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.erc20.v1beta1 import erc20_pb2 as injective_dot_erc20_dot_v1beta1_dot_erc20__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/erc20/v1beta1/query.proto\x12\x17injective.erc20.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a$injective/erc20/v1beta1/params.proto\x1a%injective/erc20/v1beta1/genesis.proto\x1a#injective/erc20/v1beta1/erc20.proto\"\x14\n\x12QueryParamsRequest\"T\n\x13QueryParamsResponse\x12=\n\x06params\x18\x01 \x01(\x0b\x32\x1f.injective.erc20.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"c\n\x19QueryAllTokenPairsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xaa\x01\n\x1aQueryAllTokenPairsResponse\x12\x43\n\x0btoken_pairs\x18\x01 \x03(\x0b\x32\".injective.erc20.v1beta1.TokenPairR\ntokenPairs\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"=\n\x1cQueryTokenPairByDenomRequest\x12\x1d\n\nbank_denom\x18\x01 \x01(\tR\tbankDenom\"b\n\x1dQueryTokenPairByDenomResponse\x12\x41\n\ntoken_pair\x18\x01 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairR\ttokenPair\"J\n#QueryTokenPairByERC20AddressRequest\x12#\n\rerc20_address\x18\x01 \x01(\tR\x0c\x65rc20Address\"i\n$QueryTokenPairByERC20AddressResponse\x12\x41\n\ntoken_pair\x18\x01 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairR\ttokenPair2\xd4\x05\n\x05Query\x12\x8c\x01\n\x06Params\x12+.injective.erc20.v1beta1.QueryParamsRequest\x1a,.injective.erc20.v1beta1.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/injective/erc20/v1beta1/params\x12\xaa\x01\n\rAllTokenPairs\x12\x32.injective.erc20.v1beta1.QueryAllTokenPairsRequest\x1a\x33.injective.erc20.v1beta1.QueryAllTokenPairsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/erc20/v1beta1/all_token_pairs\x12\xb7\x01\n\x10TokenPairByDenom\x12\x35.injective.erc20.v1beta1.QueryTokenPairByDenomRequest\x1a\x36.injective.erc20.v1beta1.QueryTokenPairByDenomResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/erc20/v1beta1/token_pair_by_denom\x12\xd4\x01\n\x17TokenPairByERC20Address\x12<.injective.erc20.v1beta1.QueryTokenPairByERC20AddressRequest\x1a=.injective.erc20.v1beta1.QueryTokenPairByERC20AddressResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/erc20/v1beta1/token_pair_by_erc20_addressB\xf4\x01\n\x1b\x63om.injective.erc20.v1beta1B\nQueryProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\nQueryProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/injective/erc20/v1beta1/params'
  _globals['_QUERY'].methods_by_name['AllTokenPairs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllTokenPairs']._serialized_options = b'\202\323\344\223\002*\022(/injective/erc20/v1beta1/all_token_pairs'
  _globals['_QUERY'].methods_by_name['TokenPairByDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TokenPairByDenom']._serialized_options = b'\202\323\344\223\002.\022,/injective/erc20/v1beta1/token_pair_by_denom'
  _globals['_QUERY'].methods_by_name['TokenPairByERC20Address']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TokenPairByERC20Address']._serialized_options = b'\202\323\344\223\0026\0224/injective/erc20/v1beta1/token_pair_by_erc20_address'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=306
  _globals['_QUERYPARAMSREQUEST']._serialized_end=326
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=328
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=412
  _globals['_QUERYALLTOKENPAIRSREQUEST']._serialized_start=414
  _globals['_QUERYALLTOKENPAIRSREQUEST']._serialized_end=513
  _globals['_QUERYALLTOKENPAIRSRESPONSE']._serialized_start=516
  _globals['_QUERYALLTOKENPAIRSRESPONSE']._serialized_end=686
  _globals['_QUERYTOKENPAIRBYDENOMREQUEST']._serialized_start=688
  _globals['_QUERYTOKENPAIRBYDENOMREQUEST']._serialized_end=749
  _globals['_QUERYTOKENPAIRBYDENOMRESPONSE']._serialized_start=751
  _globals['_QUERYTOKENPAIRBYDENOMRESPONSE']._serialized_end=849
  _globals['_QUERYTOKENPAIRBYERC20ADDRESSREQUEST']._serialized_start=851
  _globals['_QUERYTOKENPAIRBYERC20ADDRESSREQUEST']._serialized_end=925
  _globals['_QUERYTOKENPAIRBYERC20ADDRESSRESPONSE']._serialized_start=927
  _globals['_QUERYTOKENPAIRBYERC20ADDRESSRESPONSE']._serialized_end=1032
  _globals['_QUERY']._serialized_start=1035
  _globals['_QUERY']._serialized_end=1759
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/slashing/v1beta1/tx.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xa3\x01\n\tMsgUnjail\x12\x64\n\x0evalidator_addr\x18\x01 \x01(\tB=\xea\xde\x1f\x07\x61\x64\x64ress\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\xa2\xe7\xb0*\x07\x61\x64\x64ress\xa8\xe7\xb0*\x01R\rvalidatorAddr:0\x88\xa0\x1f\x00\x82\xe7\xb0*\x0evalidator_addr\x8a\xe7\xb0*\x14\x63osmos-sdk/MsgUnjail\"\x13\n\x11MsgUnjailResponse\"\xc7\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x42\n\x06params\x18\x02 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params:8\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*%cosmos-sdk/x/slashing/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xd2\x01\n\x03Msg\x12X\n\x06Unjail\x12\".cosmos.slashing.v1beta1.MsgUnjail\x1a*.cosmos.slashing.v1beta1.MsgUnjailResponse\x12j\n\x0cUpdateParams\x12(.cosmos.slashing.v1beta1.MsgUpdateParams\x1a\x30.cosmos.slashing.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xd7\x01\n\x1b\x63om.cosmos.slashing.v1beta1B\x07TxProtoP\x01Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa2\x02\x03\x43SX\xaa\x02\x17\x43osmos.Slashing.V1beta1\xca\x02\x17\x43osmos\\Slashing\\V1beta1\xe2\x02#Cosmos\\Slashing\\V1beta1\\GPBMetadata\xea\x02\x19\x43osmos::Slashing::V1beta1\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.slashing.v1beta1B\007TxProtoP\001Z-github.com/cosmos/cosmos-sdk/x/slashing/types\242\002\003CSX\252\002\027Cosmos.Slashing.V1beta1\312\002\027Cosmos\\Slashing\\V1beta1\342\002#Cosmos\\Slashing\\V1beta1\\GPBMetadata\352\002\031Cosmos::Slashing::V1beta1\250\342\036\001'
  _globals['_MSGUNJAIL'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_MSGUNJAIL'].fields_by_name['validator_addr']._serialized_options = b'\352\336\037\007address\322\264-\035cosmos.ValidatorAddressString\242\347\260*\007address\250\347\260*\001'
  _globals['_MSGUNJAIL']._loaded_options = None
  _globals['_MSGUNJAIL']._serialized_options = b'\210\240\037\000\202\347\260*\016validator_addr\212\347\260*\024cosmos-sdk/MsgUnjail'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*%cosmos-sdk/x/slashing/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUNJAIL']._serialized_start=195
  _globals['_MSGUNJAIL']._serialized_end=358
  _globals['_MSGUNJAILRESPONSE']._serialized_start=360
  _globals['_MSGUNJAILRESPONSE']._serialized_end=379
  _globals['_MSGUPDATEPARAMS']._serialized_start=382
  _globals['_MSGUPDATEPARAMS']._serialized_end=581
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=583
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=608
  _globals['_MSG']._serialized_start=611
  _globals['_MSG']._serialized_end=821
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/store/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/store/v1/types.proto\x12\x11\x63ometbft.store.v1\"=\n\x0f\x42lockStoreState\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\x03R\x04\x62\x61se\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06heightB\xbd\x01\n\x15\x63om.cometbft.store.v1B\nTypesProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/store/v1\xa2\x02\x03\x43SX\xaa\x02\x11\x43ometbft.Store.V1\xca\x02\x11\x43ometbft\\Store\\V1\xe2\x02\x1d\x43ometbft\\Store\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Store::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.store.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.store.v1B\nTypesProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/store/v1\242\002\003CSX\252\002\021Cometbft.Store.V1\312\002\021Cometbft\\Store\\V1\342\002\035Cometbft\\Store\\V1\\GPBMetadata\352\002\023Cometbft::Store::V1'
  _globals['_BLOCKSTORESTATE']._serialized_start=52
  _globals['_BLOCKSTORESTATE']._serialized_end=113
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/commitment/v1/commitment.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.ics23.v1 import proofs_pb2 as cosmos_dot_ics23_dot_v1_dot_proofs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/commitment/v1/commitment.proto\x12\x16ibc.core.commitment.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmos/ics23/v1/proofs.proto\"&\n\nMerkleRoot\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash:\x04\x88\xa0\x1f\x00\"-\n\x0cMerklePrefix\x12\x1d\n\nkey_prefix\x18\x01 \x01(\x0cR\tkeyPrefix\"\'\n\nMerklePath\x12\x19\n\x08key_path\x18\x01 \x03(\tR\x07keyPath\"G\n\x0bMerkleProof\x12\x38\n\x06proofs\x18\x01 \x03(\x0b\x32 .cosmos.ics23.v1.CommitmentProofR\x06proofsB\xe6\x01\n\x1a\x63om.ibc.core.commitment.v1B\x0f\x43ommitmentProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/23-commitment/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Commitment.V1\xca\x02\x16Ibc\\Core\\Commitment\\V1\xe2\x02\"Ibc\\Core\\Commitment\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Commitment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.commitment.v1.commitment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.commitment.v1B\017CommitmentProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/23-commitment/types\242\002\003ICC\252\002\026Ibc.Core.Commitment.V1\312\002\026Ibc\\Core\\Commitment\\V1\342\002\"Ibc\\Core\\Commitment\\V1\\GPBMetadata\352\002\031Ibc::Core::Commitment::V1'
  _globals['_MERKLEROOT']._loaded_options = None
  _globals['_MERKLEROOT']._serialized_options = b'\210\240\037\000'
  _globals['_MERKLEROOT']._serialized_start=119
  _globals['_MERKLEROOT']._serialized_end=157
  _globals['_MERKLEPREFIX']._serialized_start=159
  _globals['_MERKLEPREFIX']._serialized_end=204
  _globals['_MERKLEPATH']._serialized_start=206
  _globals['_MERKLEPATH']._serialized_end=245
  _globals['_MERKLEPROOF']._serialized_start=247
  _globals['_MERKLEPROOF']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.txfees.v1beta1 import query_pb2 as injective_dot_txfees_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.txfees.v1beta1.Query/Params',
                request_serializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.GetEipBaseFee = channel.unary_unary(
                '/injective.txfees.v1beta1.Query/GetEipBaseFee',
                request_serializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeRequest.SerializeToString,
                response_deserializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Params(self, request, context):
        """Params defines a gRPC query method that returns the tokenfactory module's
        parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEipBaseFee(self, request, context):
        """Returns the current fee market EIP fee.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'GetEipBaseFee': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEipBaseFee,
                    request_deserializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeRequest.FromString,
                    response_serializer=injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.txfees.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.txfees.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.txfees.v1beta1.Query/Params',
            injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEipBaseFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.txfees.v1beta1.Query/GetEipBaseFee',
            injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeRequest.SerializeToString,
            injective_dot_txfees_dot_v1beta1_dot_query__pb2.QueryEipBaseFeeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/connection.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/connection/v1/connection.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/commitment/v1/commitment.proto\"\x97\x02\n\rConnectionEnd\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12;\n\x08versions\x18\x02 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x08versions\x12\x33\n\x05state\x18\x03 \x01(\x0e\x32\x1d.ibc.core.connection.v1.StateR\x05state\x12N\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12!\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04R\x0b\x64\x65layPeriod:\x04\x88\xa0\x1f\x00\"\xae\x02\n\x14IdentifiedConnection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12;\n\x08versions\x18\x03 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x08versions\x12\x33\n\x05state\x18\x04 \x01(\x0e\x32\x1d.ibc.core.connection.v1.StateR\x05state\x12N\n\x0c\x63ounterparty\x18\x05 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12!\n\x0c\x64\x65lay_period\x18\x06 \x01(\x04R\x0b\x64\x65layPeriod:\x04\x88\xa0\x1f\x00\"\x9a\x01\n\x0c\x43ounterparty\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rconnection_id\x18\x02 \x01(\tR\x0c\x63onnectionId\x12\x42\n\x06prefix\x18\x03 \x01(\x0b\x32$.ibc.core.commitment.v1.MerklePrefixB\x04\xc8\xde\x1f\x00R\x06prefix:\x04\x88\xa0\x1f\x00\"#\n\x0b\x43lientPaths\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"D\n\x0f\x43onnectionPaths\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x14\n\x05paths\x18\x02 \x03(\tR\x05paths\"K\n\x07Version\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08\x66\x65\x61tures\x18\x02 \x03(\tR\x08\x66\x65\x61tures:\x04\x88\xa0\x1f\x00\"F\n\x06Params\x12<\n\x1bmax_expected_time_per_block\x18\x01 \x01(\x04R\x17maxExpectedTimePerBlock*\x99\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x1a\x04\x88\xa3\x1e\x00\x42\xe6\x01\n\x1a\x63om.ibc.core.connection.v1B\x0f\x43onnectionProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\017ConnectionProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_STATE']._loaded_options = None
  _globals['_STATE']._serialized_options = b'\210\243\036\000'
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \rUNINITIALIZED'
  _globals['_STATE'].values_by_name["STATE_INIT"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_INIT"]._serialized_options = b'\212\235 \004INIT'
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._serialized_options = b'\212\235 \007TRYOPEN'
  _globals['_STATE'].values_by_name["STATE_OPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_OPEN"]._serialized_options = b'\212\235 \004OPEN'
  _globals['_CONNECTIONEND'].fields_by_name['counterparty']._loaded_options = None
  _globals['_CONNECTIONEND'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_CONNECTIONEND']._loaded_options = None
  _globals['_CONNECTIONEND']._serialized_options = b'\210\240\037\000'
  _globals['_IDENTIFIEDCONNECTION'].fields_by_name['counterparty']._loaded_options = None
  _globals['_IDENTIFIEDCONNECTION'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_IDENTIFIEDCONNECTION']._loaded_options = None
  _globals['_IDENTIFIEDCONNECTION']._serialized_options = b'\210\240\037\000'
  _globals['_COUNTERPARTY'].fields_by_name['prefix']._loaded_options = None
  _globals['_COUNTERPARTY'].fields_by_name['prefix']._serialized_options = b'\310\336\037\000'
  _globals['_COUNTERPARTY']._loaded_options = None
  _globals['_COUNTERPARTY']._serialized_options = b'\210\240\037\000'
  _globals['_VERSION']._loaded_options = None
  _globals['_VERSION']._serialized_options = b'\210\240\037\000'
  _globals['_STATE']._serialized_start=1131
  _globals['_STATE']._serialized_end=1284
  _globals['_CONNECTIONEND']._serialized_start=131
  _globals['_CONNECTIONEND']._serialized_end=410
  _globals['_IDENTIFIEDCONNECTION']._serialized_start=413
  _globals['_IDENTIFIEDCONNECTION']._serialized_end=715
  _globals['_COUNTERPARTY']._serialized_start=718
  _globals['_COUNTERPARTY']._serialized_end=872
  _globals['_CLIENTPATHS']._serialized_start=874
  _globals['_CLIENTPATHS']._serialized_end=909
  _globals['_CONNECTIONPATHS']._serialized_start=911
  _globals['_CONNECTIONPATHS']._serialized_end=979
  _globals['_VERSION']._serialized_start=981
  _globals['_VERSION']._serialized_end=1056
  _globals['_PARAMS']._serialized_start=1058
  _globals['_PARAMS']._serialized_end=1128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1/block.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import evidence_pb2 as cometbft_dot_types_dot_v1_dot_evidence__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/types/v1/block.proto\x12\x11\x63ometbft.types.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a cometbft/types/v1/evidence.proto\x1a\x14gogoproto/gogo.proto\"\xf2\x01\n\x05\x42lock\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\x19.cometbft.types.v1.HeaderB\x04\xc8\xde\x1f\x00R\x06header\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v1.DataB\x04\xc8\xde\x1f\x00R\x04\x64\x61ta\x12\x41\n\x08\x65vidence\x18\x03 \x01(\x0b\x32\x1f.cometbft.types.v1.EvidenceListB\x04\xc8\xde\x1f\x00R\x08\x65vidence\x12:\n\x0blast_commit\x18\x04 \x01(\x0b\x32\x19.cometbft.types.v1.CommitR\nlastCommitB\xbd\x01\n\x15\x63om.cometbft.types.v1B\nBlockProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/types/v1\xa2\x02\x03\x43TX\xaa\x02\x11\x43ometbft.Types.V1\xca\x02\x11\x43ometbft\\Types\\V1\xe2\x02\x1d\x43ometbft\\Types\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.block_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.types.v1B\nBlockProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/types/v1\242\002\003CTX\252\002\021Cometbft.Types.V1\312\002\021Cometbft\\Types\\V1\342\002\035Cometbft\\Types\\V1\\GPBMetadata\352\002\023Cometbft::Types::V1'
  _globals['_BLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['data']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['evidence']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK']._serialized_start=140
  _globals['_BLOCK']._serialized_end=382
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from pyinjective.proto.injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\x1a\x11\x61mino/amino.proto\"\xa6\x01\n\x18MsgExecuteContractCompat\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08\x63ontract\x18\x02 \x01(\tR\x08\x63ontract\x12\x10\n\x03msg\x18\x03 \x01(\tR\x03msg\x12\x14\n\x05\x66unds\x18\x04 \x01(\tR\x05\x66unds:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1ewasmx/MsgExecuteContractCompat\"6\n MsgExecuteContractCompatResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\xe4\x01\n\x11MsgUpdateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tgas_limit\x18\x03 \x01(\x04R\x08gasLimit\x12\x1b\n\tgas_price\x18\x04 \x01(\x04R\x08gasPrice\x12)\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01R\x0c\x61\x64minAddress:\'\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17wasmx/MsgUpdateContract\"\x1b\n\x19MsgUpdateContractResponse\"\x83\x01\n\x13MsgActivateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19wasmx/MsgActivateContract\"\x1d\n\x1bMsgActivateContractResponse\"\x87\x01\n\x15MsgDeactivateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1bwasmx/MsgDeactivateContract\"\x1f\n\x1dMsgDeactivateContractResponse\"\xad\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:(\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x15wasmx/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xd3\x01\n\x13MsgRegisterContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12y\n\x1d\x63ontract_registration_request\x18\x02 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00R\x1b\x63ontractRegistrationRequest:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19wasmx/MsgRegisterContract\"\x1d\n\x1bMsgRegisterContractResponse2\xc1\x05\n\x03Msg\x12t\n\x1cUpdateRegistryContractParams\x12%.injective.wasmx.v1.MsgUpdateContract\x1a-.injective.wasmx.v1.MsgUpdateContractResponse\x12t\n\x18\x41\x63tivateRegistryContract\x12\'.injective.wasmx.v1.MsgActivateContract\x1a/.injective.wasmx.v1.MsgActivateContractResponse\x12z\n\x1a\x44\x65\x61\x63tivateRegistryContract\x12).injective.wasmx.v1.MsgDeactivateContract\x1a\x31.injective.wasmx.v1.MsgDeactivateContractResponse\x12{\n\x15\x45xecuteContractCompat\x12,.injective.wasmx.v1.MsgExecuteContractCompat\x1a\x34.injective.wasmx.v1.MsgExecuteContractCompatResponse\x12`\n\x0cUpdateParams\x12#.injective.wasmx.v1.MsgUpdateParams\x1a+.injective.wasmx.v1.MsgUpdateParamsResponse\x12l\n\x10RegisterContract\x12\'.injective.wasmx.v1.MsgRegisterContract\x1a/.injective.wasmx.v1.MsgRegisterContractResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xd8\x01\n\x16\x63om.injective.wasmx.v1B\x07TxProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\007TxProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_MSGEXECUTECONTRACTCOMPAT']._loaded_options = None
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036wasmx/MsgExecuteContractCompat'
  _globals['_MSGUPDATECONTRACT'].fields_by_name['admin_address']._loaded_options = None
  _globals['_MSGUPDATECONTRACT'].fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _globals['_MSGUPDATECONTRACT']._loaded_options = None
  _globals['_MSGUPDATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\027wasmx/MsgUpdateContract'
  _globals['_MSGACTIVATECONTRACT']._loaded_options = None
  _globals['_MSGACTIVATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031wasmx/MsgActivateContract'
  _globals['_MSGDEACTIVATECONTRACT']._loaded_options = None
  _globals['_MSGDEACTIVATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033wasmx/MsgDeactivateContract'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\025wasmx/MsgUpdateParams'
  _globals['_MSGREGISTERCONTRACT'].fields_by_name['contract_registration_request']._loaded_options = None
  _globals['_MSGREGISTERCONTRACT'].fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _globals['_MSGREGISTERCONTRACT']._loaded_options = None
  _globals['_MSGREGISTERCONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031wasmx/MsgRegisterContract'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_start=239
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_end=405
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_start=407
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_end=461
  _globals['_MSGUPDATECONTRACT']._serialized_start=464
  _globals['_MSGUPDATECONTRACT']._serialized_end=692
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_start=694
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_end=721
  _globals['_MSGACTIVATECONTRACT']._serialized_start=724
  _globals['_MSGACTIVATECONTRACT']._serialized_end=855
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_start=857
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_end=886
  _globals['_MSGDEACTIVATECONTRACT']._serialized_start=889
  _globals['_MSGDEACTIVATECONTRACT']._serialized_end=1024
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_start=1026
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_end=1057
  _globals['_MSGUPDATEPARAMS']._serialized_start=1060
  _globals['_MSGUPDATEPARAMS']._serialized_end=1233
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1235
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1260
  _globals['_MSGREGISTERCONTRACT']._serialized_start=1263
  _globals['_MSGREGISTERCONTRACT']._serialized_end=1474
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_start=1476
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_end=1505
  _globals['_MSG']._serialized_start=1508
  _globals['_MSG']._serialized_end=2213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_archiver_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_archiver_rpc.proto\x12\x16injective_archiver_rpc\"J\n\x0e\x42\x61lanceRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"k\n\x0f\x42\x61lanceResponse\x12X\n\x12historical_balance\x18\x01 \x01(\x0b\x32).injective_archiver_rpc.HistoricalBalanceR\x11historicalBalance\"/\n\x11HistoricalBalance\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v\"G\n\x0bRpnlRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"_\n\x0cRpnlResponse\x12O\n\x0fhistorical_rpnl\x18\x01 \x01(\x0b\x32&.injective_archiver_rpc.HistoricalRPNLR\x0ehistoricalRpnl\",\n\x0eHistoricalRPNL\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v\"J\n\x0eVolumesRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"k\n\x0fVolumesResponse\x12X\n\x12historical_volumes\x18\x01 \x01(\x0b\x32).injective_archiver_rpc.HistoricalVolumesR\x11historicalVolumes\"/\n\x11HistoricalVolumes\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v\"\x81\x01\n\x15PnlLeaderboardRequest\x12\x1d\n\nstart_date\x18\x01 \x01(\x12R\tstartDate\x12\x19\n\x08\x65nd_date\x18\x02 \x01(\x12R\x07\x65ndDate\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\x12\x18\n\x07\x61\x63\x63ount\x18\x04 \x01(\tR\x07\x61\x63\x63ount\"\xdf\x01\n\x16PnlLeaderboardResponse\x12\x1d\n\nfirst_date\x18\x01 \x01(\tR\tfirstDate\x12\x1b\n\tlast_date\x18\x02 \x01(\tR\x08lastDate\x12@\n\x07leaders\x18\x03 \x03(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\x07leaders\x12G\n\x0b\x61\x63\x63ount_row\x18\x04 \x01(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\naccountRow\"h\n\x0eLeaderboardRow\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x10\n\x03pnl\x18\x02 \x01(\x01R\x03pnl\x12\x16\n\x06volume\x18\x03 \x01(\x01R\x06volume\x12\x12\n\x04rank\x18\x04 \x01(\x11R\x04rank\"\x81\x01\n\x15VolLeaderboardRequest\x12\x1d\n\nstart_date\x18\x01 \x01(\x12R\tstartDate\x12\x19\n\x08\x65nd_date\x18\x02 \x01(\x12R\x07\x65ndDate\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\x12\x18\n\x07\x61\x63\x63ount\x18\x04 \x01(\tR\x07\x61\x63\x63ount\"\xdf\x01\n\x16VolLeaderboardResponse\x12\x1d\n\nfirst_date\x18\x01 \x01(\tR\tfirstDate\x12\x1b\n\tlast_date\x18\x02 \x01(\tR\x08lastDate\x12@\n\x07leaders\x18\x03 \x03(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\x07leaders\x12G\n\x0b\x61\x63\x63ount_row\x18\x04 \x01(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\naccountRow\"v\n$PnlLeaderboardFixedResolutionRequest\x12\x1e\n\nresolution\x18\x01 \x01(\tR\nresolution\x12\x14\n\x05limit\x18\x02 \x01(\x11R\x05limit\x12\x18\n\x07\x61\x63\x63ount\x18\x03 \x01(\tR\x07\x61\x63\x63ount\"\xee\x01\n%PnlLeaderboardFixedResolutionResponse\x12\x1d\n\nfirst_date\x18\x01 \x01(\tR\tfirstDate\x12\x1b\n\tlast_date\x18\x02 \x01(\tR\x08lastDate\x12@\n\x07leaders\x18\x03 \x03(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\x07leaders\x12G\n\x0b\x61\x63\x63ount_row\x18\x04 \x01(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\naccountRow\"v\n$VolLeaderboardFixedResolutionRequest\x12\x1e\n\nresolution\x18\x01 \x01(\tR\nresolution\x12\x14\n\x05limit\x18\x02 \x01(\x11R\x05limit\x12\x18\n\x07\x61\x63\x63ount\x18\x03 \x01(\tR\x07\x61\x63\x63ount\"\xee\x01\n%VolLeaderboardFixedResolutionResponse\x12\x1d\n\nfirst_date\x18\x01 \x01(\tR\tfirstDate\x12\x1b\n\tlast_date\x18\x02 \x01(\tR\x08lastDate\x12@\n\x07leaders\x18\x03 \x03(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\x07leaders\x12G\n\x0b\x61\x63\x63ount_row\x18\x04 \x01(\x0b\x32&.injective_archiver_rpc.LeaderboardRowR\naccountRow\"W\n\x13\x44\x65nomHoldersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\"z\n\x14\x44\x65nomHoldersResponse\x12\x38\n\x07holders\x18\x01 \x03(\x0b\x32\x1e.injective_archiver_rpc.HolderR\x07holders\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\x12\x14\n\x05total\x18\x03 \x01(\x11R\x05total\"K\n\x06Holder\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\"\xd8\x01\n\x17HistoricalTradesRequest\x12\x1d\n\nfrom_block\x18\x01 \x01(\x04R\tfromBlock\x12\x1b\n\tend_block\x18\x02 \x01(\x04R\x08\x65ndBlock\x12\x1b\n\tfrom_time\x18\x03 \x01(\x12R\x08\x66romTime\x12\x19\n\x08\x65nd_time\x18\x04 \x01(\x12R\x07\x65ndTime\x12\x19\n\x08per_page\x18\x05 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x06 \x01(\tR\x05token\x12\x18\n\x07\x61\x63\x63ount\x18\x07 \x01(\tR\x07\x61\x63\x63ount\"\xad\x01\n\x18HistoricalTradesResponse\x12?\n\x06trades\x18\x01 \x03(\x0b\x32\'.injective_archiver_rpc.HistoricalTradeR\x06trades\x12\x1f\n\x0blast_height\x18\x02 \x01(\x04R\nlastHeight\x12\x1b\n\tlast_time\x18\x03 \x01(\x12R\x08lastTime\x12\x12\n\x04next\x18\x04 \x03(\tR\x04next\"\xe7\x03\n\x0fHistoricalTrade\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\'\n\x0ftrade_direction\x18\x04 \x01(\tR\x0etradeDirection\x12\x38\n\x05price\x18\x05 \x01(\x0b\x32\".injective_archiver_rpc.PriceLevelR\x05price\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\tR\x03\x66\x65\x65\x12\x1f\n\x0b\x65xecuted_at\x18\x07 \x01(\x12R\nexecutedAt\x12\'\n\x0f\x65xecuted_height\x18\x08 \x01(\x04R\x0e\x65xecutedHeight\x12#\n\rfee_recipient\x18\t \x01(\tR\x0c\x66\x65\x65Recipient\x12%\n\x0e\x65xecution_side\x18\n \x01(\tR\rexecutionSide\x12\x1b\n\tusd_value\x18\x0b \x01(\tR\x08usdValue\x12\x14\n\x05\x66lags\x18\x0c \x03(\tR\x05\x66lags\x12\x1f\n\x0bmarket_type\x18\r \x01(\tR\nmarketType\x12\x19\n\x08trade_id\x18\x0e \x01(\tR\x07tradeId\"\\\n\nPriceLevel\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp2\xa3\x08\n\x14InjectiveArchiverRPC\x12Z\n\x07\x42\x61lance\x12&.injective_archiver_rpc.BalanceRequest\x1a\'.injective_archiver_rpc.BalanceResponse\x12Q\n\x04Rpnl\x12#.injective_archiver_rpc.RpnlRequest\x1a$.injective_archiver_rpc.RpnlResponse\x12Z\n\x07Volumes\x12&.injective_archiver_rpc.VolumesRequest\x1a\'.injective_archiver_rpc.VolumesResponse\x12o\n\x0ePnlLeaderboard\x12-.injective_archiver_rpc.PnlLeaderboardRequest\x1a..injective_archiver_rpc.PnlLeaderboardResponse\x12o\n\x0eVolLeaderboard\x12-.injective_archiver_rpc.VolLeaderboardRequest\x1a..injective_archiver_rpc.VolLeaderboardResponse\x12\x9c\x01\n\x1dPnlLeaderboardFixedResolution\x12<.injective_archiver_rpc.PnlLeaderboardFixedResolutionRequest\x1a=.injective_archiver_rpc.PnlLeaderboardFixedResolutionResponse\x12\x9c\x01\n\x1dVolLeaderboardFixedResolution\x12<.injective_archiver_rpc.VolLeaderboardFixedResolutionRequest\x1a=.injective_archiver_rpc.VolLeaderboardFixedResolutionResponse\x12i\n\x0c\x44\x65nomHolders\x12+.injective_archiver_rpc.DenomHoldersRequest\x1a,.injective_archiver_rpc.DenomHoldersResponse\x12u\n\x10HistoricalTrades\x12/.injective_archiver_rpc.HistoricalTradesRequest\x1a\x30.injective_archiver_rpc.HistoricalTradesResponseB\xc2\x01\n\x1a\x63om.injective_archiver_rpcB\x19InjectiveArchiverRpcProtoP\x01Z\x19/injective_archiver_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveArchiverRpc\xca\x02\x14InjectiveArchiverRpc\xe2\x02 InjectiveArchiverRpc\\GPBMetadata\xea\x02\x14InjectiveArchiverRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_archiver_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_archiver_rpcB\031InjectiveArchiverRpcProtoP\001Z\031/injective_archiver_rpcpb\242\002\003IXX\252\002\024InjectiveArchiverRpc\312\002\024InjectiveArchiverRpc\342\002 InjectiveArchiverRpc\\GPBMetadata\352\002\024InjectiveArchiverRpc'
  _globals['_BALANCEREQUEST']._serialized_start=65
  _globals['_BALANCEREQUEST']._serialized_end=139
  _globals['_BALANCERESPONSE']._serialized_start=141
  _globals['_BALANCERESPONSE']._serialized_end=248
  _globals['_HISTORICALBALANCE']._serialized_start=250
  _globals['_HISTORICALBALANCE']._serialized_end=297
  _globals['_RPNLREQUEST']._serialized_start=299
  _globals['_RPNLREQUEST']._serialized_end=370
  _globals['_RPNLRESPONSE']._serialized_start=372
  _globals['_RPNLRESPONSE']._serialized_end=467
  _globals['_HISTORICALRPNL']._serialized_start=469
  _globals['_HISTORICALRPNL']._serialized_end=513
  _globals['_VOLUMESREQUEST']._serialized_start=515
  _globals['_VOLUMESREQUEST']._serialized_end=589
  _globals['_VOLUMESRESPONSE']._serialized_start=591
  _globals['_VOLUMESRESPONSE']._serialized_end=698
  _globals['_HISTORICALVOLUMES']._serialized_start=700
  _globals['_HISTORICALVOLUMES']._serialized_end=747
  _globals['_PNLLEADERBOARDREQUEST']._serialized_start=750
  _globals['_PNLLEADERBOARDREQUEST']._serialized_end=879
  _globals['_PNLLEADERBOARDRESPONSE']._serialized_start=882
  _globals['_PNLLEADERBOARDRESPONSE']._serialized_end=1105
  _globals['_LEADERBOARDROW']._serialized_start=1107
  _globals['_LEADERBOARDROW']._serialized_end=1211
  _globals['_VOLLEADERBOARDREQUEST']._serialized_start=1214
  _globals['_VOLLEADERBOARDREQUEST']._serialized_end=1343
  _globals['_VOLLEADERBOARDRESPONSE']._serialized_start=1346
  _globals['_VOLLEADERBOARDRESPONSE']._serialized_end=1569
  _globals['_PNLLEADERBOARDFIXEDRESOLUTIONREQUEST']._serialized_start=1571
  _globals['_PNLLEADERBOARDFIXEDRESOLUTIONREQUEST']._serialized_end=1689
  _globals['_PNLLEADERBOARDFIXEDRESOLUTIONRESPONSE']._serialized_start=1692
  _globals['_PNLLEADERBOARDFIXEDRESOLUTIONRESPONSE']._serialized_end=1930
  _globals['_VOLLEADERBOARDFIXEDRESOLUTIONREQUEST']._serialized_start=1932
  _globals['_VOLLEADERBOARDFIXEDRESOLUTIONREQUEST']._serialized_end=2050
  _globals['_VOLLEADERBOARDFIXEDRESOLUTIONRESPONSE']._serialized_start=2053
  _globals['_VOLLEADERBOARDFIXEDRESOLUTIONRESPONSE']._serialized_end=2291
  _globals['_DENOMHOLDERSREQUEST']._serialized_start=2293
  _globals['_DENOMHOLDERSREQUEST']._serialized_end=2380
  _globals['_DENOMHOLDERSRESPONSE']._serialized_start=2382
  _globals['_DENOMHOLDERSRESPONSE']._serialized_end=2504
  _globals['_HOLDER']._serialized_start=2506
  _globals['_HOLDER']._serialized_end=2581
  _globals['_HISTORICALTRADESREQUEST']._serialized_start=2584
  _globals['_HISTORICALTRADESREQUEST']._serialized_end=2800
  _globals['_HISTORICALTRADESRESPONSE']._serialized_start=2803
  _globals['_HISTORICALTRADESRESPONSE']._serialized_end=2976
  _globals['_HISTORICALTRADE']._serialized_start=2979
  _globals['_HISTORICALTRADE']._serialized_end=3466
  _globals['_PRICELEVEL']._serialized_start=3468
  _globals['_PRICELEVEL']._serialized_end=3560
  _globals['_INJECTIVEARCHIVERRPC']._serialized_start=3563
  _globals['_INJECTIVEARCHIVERRPC']._serialized_end=4622
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/auction.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/auction/v1beta1/auction.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"\xf7\x01\n\x06Params\x12%\n\x0e\x61uction_period\x18\x01 \x01(\x03R\rauctionPeriod\x12\x61\n\x1bmin_next_bid_increment_rate\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17minNextBidIncrementRate\x12J\n\x12inj_basket_max_cap\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0finjBasketMaxCap:\x17\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x0e\x61uction/Params\"\x9e\x01\n\x03\x42id\x12\x33\n\x06\x62idder\x18\x01 \x01(\tB\x1b\xea\xde\x1f\x06\x62idder\xf2\xde\x1f\ryaml:\"bidder\"R\x06\x62idder\x12\x62\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.CoinR\x06\x61mount\"\xa5\x01\n\x11LastAuctionResult\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x62\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.CoinR\x06\x61mount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\"\x9c\x01\n\x08\x45ventBid\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x62\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.CoinR\x06\x61mount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\"\xa6\x01\n\x12\x45ventAuctionResult\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x62\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB/\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.CoinR\x06\x61mount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\"\xc0\x01\n\x11\x45ventAuctionStart\x12\x14\n\x05round\x18\x01 \x01(\x04R\x05round\x12)\n\x10\x65nding_timestamp\x18\x02 \x01(\x03R\x0f\x65ndingTimestamp\x12j\n\nnew_basket\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\tnewBasketB\x82\x02\n\x1d\x63om.injective.auction.v1beta1B\x0c\x41uctionProtoP\x01ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\xa2\x02\x03IAX\xaa\x02\x19Injective.Auction.V1beta1\xca\x02\x19Injective\\Auction\\V1beta1\xe2\x02%Injective\\Auction\\V1beta1\\GPBMetadata\xea\x02\x1bInjective::Auction::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.auction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.injective.auction.v1beta1B\014AuctionProtoP\001ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\242\002\003IAX\252\002\031Injective.Auction.V1beta1\312\002\031Injective\\Auction\\V1beta1\342\002%Injective\\Auction\\V1beta1\\GPBMetadata\352\002\033Injective::Auction::V1beta1'
  _globals['_PARAMS'].fields_by_name['min_next_bid_increment_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_next_bid_increment_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PARAMS'].fields_by_name['inj_basket_max_cap']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['inj_basket_max_cap']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\016auction/Params'
  _globals['_BID'].fields_by_name['bidder']._loaded_options = None
  _globals['_BID'].fields_by_name['bidder']._serialized_options = b'\352\336\037\006bidder\362\336\037\ryaml:\"bidder\"'
  _globals['_BID'].fields_by_name['amount']._loaded_options = None
  _globals['_BID'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_LASTAUCTIONRESULT'].fields_by_name['amount']._loaded_options = None
  _globals['_LASTAUCTIONRESULT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_EVENTBID'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTBID'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_EVENTAUCTIONRESULT'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTAUCTIONRESULT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_EVENTAUCTIONSTART'].fields_by_name['new_basket']._loaded_options = None
  _globals['_EVENTAUCTIONSTART'].fields_by_name['new_basket']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PARAMS']._serialized_start=144
  _globals['_PARAMS']._serialized_end=391
  _globals['_BID']._serialized_start=394
  _globals['_BID']._serialized_end=552
  _globals['_LASTAUCTIONRESULT']._serialized_start=555
  _globals['_LASTAUCTIONRESULT']._serialized_end=720
  _globals['_EVENTBID']._serialized_start=723
  _globals['_EVENTBID']._serialized_end=879
  _globals['_EVENTAUCTIONRESULT']._serialized_start=882
  _globals['_EVENTAUCTIONRESULT']._serialized_end=1048
  _globals['_EVENTAUCTIONSTART']._serialized_start=1051
  _globals['_EVENTAUCTIONSTART']._serialized_end=1243
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/auction/v1beta1/tx.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\'injective/auction/v1beta1/auction.proto\x1a\x11\x61mino/amino.proto\"\x9e\x01\n\x06MsgBid\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12>\n\nbid_amount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\tbidAmount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x0e\x61uction/MsgBid\"\x10\n\x0eMsgBidResponse\"\xb6\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12?\n\x06params\x18\x02 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:*\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x17\x61uction/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xd1\x01\n\x03Msg\x12S\n\x03\x42id\x12!.injective.auction.v1beta1.MsgBid\x1a).injective.auction.v1beta1.MsgBidResponse\x12n\n\x0cUpdateParams\x12*.injective.auction.v1beta1.MsgUpdateParams\x1a\x32.injective.auction.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xfd\x01\n\x1d\x63om.injective.auction.v1beta1B\x07TxProtoP\x01ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\xa2\x02\x03IAX\xaa\x02\x19Injective.Auction.V1beta1\xca\x02\x19Injective\\Auction\\V1beta1\xe2\x02%Injective\\Auction\\V1beta1\\GPBMetadata\xea\x02\x1bInjective::Auction::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.injective.auction.v1beta1B\007TxProtoP\001ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\242\002\003IAX\252\002\031Injective.Auction.V1beta1\312\002\031Injective\\Auction\\V1beta1\342\002%Injective\\Auction\\V1beta1\\GPBMetadata\352\002\033Injective::Auction::V1beta1'
  _globals['_MSGBID'].fields_by_name['bid_amount']._loaded_options = None
  _globals['_MSGBID'].fields_by_name['bid_amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGBID']._loaded_options = None
  _globals['_MSGBID']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\016auction/MsgBid'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\027auction/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGBID']._serialized_start=232
  _globals['_MSGBID']._serialized_end=390
  _globals['_MSGBIDRESPONSE']._serialized_start=392
  _globals['_MSGBIDRESPONSE']._serialized_end=408
  _globals['_MSGUPDATEPARAMS']._serialized_start=411
  _globals['_MSGUPDATEPARAMS']._serialized_end=593
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=595
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=620
  _globals['_MSG']._serialized_start=623
  _globals['_MSG']._serialized_end=832
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.peggy.v1 import genesis_pb2 as injective_dot_peggy_dot_v1_dot_genesis__pb2
from pyinjective.proto.injective.peggy.v1 import params_pb2 as injective_dot_peggy_dot_v1_dot_params__pb2
from pyinjective.proto.injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from pyinjective.proto.injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from pyinjective.proto.injective.peggy.v1 import pool_pb2 as injective_dot_peggy_dot_v1_dot_pool__pb2
from pyinjective.proto.injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/peggy/v1/query.proto\x12\x12injective.peggy.v1\x1a injective/peggy/v1/genesis.proto\x1a\x1finjective/peggy/v1/params.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1dinjective/peggy/v1/pool.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\"\x14\n\x12QueryParamsRequest\"O\n\x13QueryParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1b\n\x19QueryCurrentValsetRequest\"P\n\x1aQueryCurrentValsetResponse\x12\x32\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x06valset\"1\n\x19QueryValsetRequestRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\"P\n\x1aQueryValsetRequestResponse\x12\x32\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x06valset\"K\n\x19QueryValsetConfirmRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\\\n\x1aQueryValsetConfirmResponse\x12>\n\x07\x63onfirm\x18\x01 \x01(\x0b\x32$.injective.peggy.v1.MsgValsetConfirmR\x07\x63onfirm\"9\n!QueryValsetConfirmsByNonceRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\"f\n\"QueryValsetConfirmsByNonceResponse\x12@\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirmR\x08\x63onfirms\" \n\x1eQueryLastValsetRequestsRequest\"W\n\x1fQueryLastValsetRequestsResponse\x12\x34\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x07valsets\"F\n*QueryLastPendingValsetRequestByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"c\n+QueryLastPendingValsetRequestByAddrResponse\x12\x34\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x07valsets\"\x16\n\x14QueryBatchFeeRequest\"T\n\x15QueryBatchFeeResponse\x12;\n\tbatchFees\x18\x01 \x03(\x0b\x32\x1d.injective.peggy.v1.BatchFeesR\tbatchFees\"E\n)QueryLastPendingBatchRequestByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"g\n*QueryLastPendingBatchRequestByAddrResponse\x12\x39\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x05\x62\x61tch\"\x1f\n\x1dQueryOutgoingTxBatchesRequest\"_\n\x1eQueryOutgoingTxBatchesResponse\x12=\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x07\x62\x61tches\"b\n\x1fQueryBatchRequestByNonceRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\"]\n QueryBatchRequestByNonceResponse\x12\x39\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x05\x62\x61tch\"\\\n\x19QueryBatchConfirmsRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\"]\n\x1aQueryBatchConfirmsResponse\x12?\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatchR\x08\x63onfirms\"7\n\x1bQueryLastEventByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"l\n\x1cQueryLastEventByAddrResponse\x12L\n\x10last_claim_event\x18\x01 \x01(\x0b\x32\".injective.peggy.v1.LastClaimEventR\x0elastClaimEvent\"0\n\x18QueryERC20ToDenomRequest\x12\x14\n\x05\x65rc20\x18\x01 \x01(\tR\x05\x65rc20\"^\n\x19QueryERC20ToDenomResponse\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12+\n\x11\x63osmos_originated\x18\x02 \x01(\x08R\x10\x63osmosOriginated\"0\n\x18QueryDenomToERC20Request\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"^\n\x19QueryDenomToERC20Response\x12\x14\n\x05\x65rc20\x18\x01 \x01(\tR\x05\x65rc20\x12+\n\x11\x63osmos_originated\x18\x02 \x01(\x08R\x10\x63osmosOriginated\"R\n#QueryDelegateKeysByValidatorAddress\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\"\x81\x01\n+QueryDelegateKeysByValidatorAddressResponse\x12\x1f\n\x0b\x65th_address\x18\x01 \x01(\tR\nethAddress\x12\x31\n\x14orchestrator_address\x18\x02 \x01(\tR\x13orchestratorAddress\"@\n\x1dQueryDelegateKeysByEthAddress\x12\x1f\n\x0b\x65th_address\x18\x01 \x01(\tR\nethAddress\"\x87\x01\n%QueryDelegateKeysByEthAddressResponse\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\x31\n\x14orchestrator_address\x18\x02 \x01(\tR\x13orchestratorAddress\"[\n&QueryDelegateKeysByOrchestratorAddress\x12\x31\n\x14orchestrator_address\x18\x01 \x01(\tR\x13orchestratorAddress\"~\n.QueryDelegateKeysByOrchestratorAddressResponse\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\x1f\n\x0b\x65th_address\x18\x02 \x01(\tR\nethAddress\">\n\x15QueryPendingSendToEth\x12%\n\x0esender_address\x18\x01 \x01(\tR\rsenderAddress\"\xd2\x01\n\x1dQueryPendingSendToEthResponse\x12X\n\x14transfers_in_batches\x18\x01 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTxR\x12transfersInBatches\x12W\n\x13unbatched_transfers\x18\x02 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTxR\x12unbatchedTransfers\"\x19\n\x17QueryModuleStateRequest\"R\n\x18QueryModuleStateResponse\x12\x36\n\x05state\x18\x01 \x01(\x0b\x32 .injective.peggy.v1.GenesisStateR\x05state\"\x16\n\x14MissingNoncesRequest\"F\n\x15MissingNoncesResponse\x12-\n\x12operator_addresses\x18\x01 \x03(\tR\x11operatorAddresses2\xc6\x1a\n\x05Query\x12s\n\x06Params\x12&.injective.peggy.v1.QueryParamsRequest\x1a\'.injective.peggy.v1.QueryParamsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/params\x12\x90\x01\n\rCurrentValset\x12-.injective.peggy.v1.QueryCurrentValsetRequest\x1a..injective.peggy.v1.QueryCurrentValsetResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/current\x12\x88\x01\n\rValsetRequest\x12-.injective.peggy.v1.QueryValsetRequestRequest\x1a..injective.peggy.v1.QueryValsetRequestResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/valset\x12\x90\x01\n\rValsetConfirm\x12-.injective.peggy.v1.QueryValsetConfirmRequest\x1a..injective.peggy.v1.QueryValsetConfirmResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/confirm\x12\xaa\x01\n\x15ValsetConfirmsByNonce\x12\x35.injective.peggy.v1.QueryValsetConfirmsByNonceRequest\x1a\x36.injective.peggy.v1.QueryValsetConfirmsByNonceResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/confirms/{nonce}\x12\xa0\x01\n\x12LastValsetRequests\x12\x32.injective.peggy.v1.QueryLastValsetRequestsRequest\x1a\x33.injective.peggy.v1.QueryLastValsetRequestsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/peggy/v1/valset/requests\x12\xc0\x01\n\x1eLastPendingValsetRequestByAddr\x12>.injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest\x1a?.injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/peggy/v1/valset/last\x12\x9e\x01\n\x0fLastEventByAddr\x12/.injective.peggy.v1.QueryLastEventByAddrRequest\x1a\x30.injective.peggy.v1.QueryLastEventByAddrResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /peggy/v1/oracle/event/{address}\x12\x9a\x01\n\x13GetPendingSendToEth\x12).injective.peggy.v1.QueryPendingSendToEth\x1a\x31.injective.peggy.v1.QueryPendingSendToEthResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/peggy/v1/pending_send_to_eth\x12}\n\tBatchFees\x12(.injective.peggy.v1.QueryBatchFeeRequest\x1a).injective.peggy.v1.QueryBatchFeeResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/peggy/v1/batchfees\x12\x9e\x01\n\x11OutgoingTxBatches\x12\x31.injective.peggy.v1.QueryOutgoingTxBatchesRequest\x1a\x32.injective.peggy.v1.QueryOutgoingTxBatchesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/batch/outgoingtx\x12\xbc\x01\n\x1dLastPendingBatchRequestByAddr\x12=.injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest\x1a>.injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/peggy/v1/batch/last\x12\x99\x01\n\x13\x42\x61tchRequestByNonce\x12\x33.injective.peggy.v1.QueryBatchRequestByNonceRequest\x1a\x34.injective.peggy.v1.QueryBatchRequestByNonceResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/peggy/v1/batch\x12\x90\x01\n\rBatchConfirms\x12-.injective.peggy.v1.QueryBatchConfirmsRequest\x1a..injective.peggy.v1.QueryBatchConfirmsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/batch/confirms\x12\x9f\x01\n\x0c\x45RC20ToDenom\x12,.injective.peggy.v1.QueryERC20ToDenomRequest\x1a-.injective.peggy.v1.QueryERC20ToDenomResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/erc20_to_denom\x12\x9f\x01\n\x0c\x44\x65nomToERC20\x12,.injective.peggy.v1.QueryDenomToERC20Request\x1a-.injective.peggy.v1.QueryDenomToERC20Response\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/denom_to_erc20\x12\xc9\x01\n\x19GetDelegateKeyByValidator\x12\x37.injective.peggy.v1.QueryDelegateKeysByValidatorAddress\x1a?.injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/query_delegate_keys_by_validator\x12\xb1\x01\n\x13GetDelegateKeyByEth\x12\x31.injective.peggy.v1.QueryDelegateKeysByEthAddress\x1a\x39.injective.peggy.v1.QueryDelegateKeysByEthAddressResponse\",\x82\xd3\xe4\x93\x02&\x12$/peggy/v1/query_delegate_keys_by_eth\x12\xd5\x01\n\x1cGetDelegateKeyByOrchestrator\x12:.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress\x1a\x42.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse\"5\x82\xd3\xe4\x93\x02/\x12-/peggy/v1/query_delegate_keys_by_orchestrator\x12\x8d\x01\n\x10PeggyModuleState\x12+.injective.peggy.v1.QueryModuleStateRequest\x1a,.injective.peggy.v1.QueryModuleStateResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/peggy/v1/module_state\x12\x8b\x01\n\x12MissingPeggoNonces\x12(.injective.peggy.v1.MissingNoncesRequest\x1a).injective.peggy.v1.MissingNoncesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/missing_noncesB\xdb\x01\n\x16\x63om.injective.peggy.v1B\nQueryProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\nQueryProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/params'
  _globals['_QUERY'].methods_by_name['CurrentValset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CurrentValset']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/current'
  _globals['_QUERY'].methods_by_name['ValsetRequest']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetRequest']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/valset'
  _globals['_QUERY'].methods_by_name['ValsetConfirm']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetConfirm']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/confirm'
  _globals['_QUERY'].methods_by_name['ValsetConfirmsByNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetConfirmsByNonce']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/confirms/{nonce}'
  _globals['_QUERY'].methods_by_name['LastValsetRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastValsetRequests']._serialized_options = b'\202\323\344\223\002\033\022\031/peggy/v1/valset/requests'
  _globals['_QUERY'].methods_by_name['LastPendingValsetRequestByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastPendingValsetRequestByAddr']._serialized_options = b'\202\323\344\223\002\027\022\025/peggy/v1/valset/last'
  _globals['_QUERY'].methods_by_name['LastEventByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastEventByAddr']._serialized_options = b'\202\323\344\223\002\"\022 /peggy/v1/oracle/event/{address}'
  _globals['_QUERY'].methods_by_name['GetPendingSendToEth']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingSendToEth']._serialized_options = b'\202\323\344\223\002\037\022\035/peggy/v1/pending_send_to_eth'
  _globals['_QUERY'].methods_by_name['BatchFees']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchFees']._serialized_options = b'\202\323\344\223\002\025\022\023/peggy/v1/batchfees'
  _globals['_QUERY'].methods_by_name['OutgoingTxBatches']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OutgoingTxBatches']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/batch/outgoingtx'
  _globals['_QUERY'].methods_by_name['LastPendingBatchRequestByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastPendingBatchRequestByAddr']._serialized_options = b'\202\323\344\223\002\026\022\024/peggy/v1/batch/last'
  _globals['_QUERY'].methods_by_name['BatchRequestByNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchRequestByNonce']._serialized_options = b'\202\323\344\223\002\021\022\017/peggy/v1/batch'
  _globals['_QUERY'].methods_by_name['BatchConfirms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchConfirms']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/batch/confirms'
  _globals['_QUERY'].methods_by_name['ERC20ToDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ERC20ToDenom']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/erc20_to_denom'
  _globals['_QUERY'].methods_by_name['DenomToERC20']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomToERC20']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/denom_to_erc20'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByValidator']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/query_delegate_keys_by_validator'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByEth']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByEth']._serialized_options = b'\202\323\344\223\002&\022$/peggy/v1/query_delegate_keys_by_eth'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByOrchestrator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByOrchestrator']._serialized_options = b'\202\323\344\223\002/\022-/peggy/v1/query_delegate_keys_by_orchestrator'
  _globals['_QUERY'].methods_by_name['PeggyModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PeggyModuleState']._serialized_options = b'\202\323\344\223\002\030\022\026/peggy/v1/module_state'
  _globals['_QUERY'].methods_by_name['MissingPeggoNonces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MissingPeggoNonces']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/missing_nonces'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=299
  _globals['_QUERYPARAMSREQUEST']._serialized_end=319
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=321
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=400
  _globals['_QUERYCURRENTVALSETREQUEST']._serialized_start=402
  _globals['_QUERYCURRENTVALSETREQUEST']._serialized_end=429
  _globals['_QUERYCURRENTVALSETRESPONSE']._serialized_start=431
  _globals['_QUERYCURRENTVALSETRESPONSE']._serialized_end=511
  _globals['_QUERYVALSETREQUESTREQUEST']._serialized_start=513
  _globals['_QUERYVALSETREQUESTREQUEST']._serialized_end=562
  _globals['_QUERYVALSETREQUESTRESPONSE']._serialized_start=564
  _globals['_QUERYVALSETREQUESTRESPONSE']._serialized_end=644
  _globals['_QUERYVALSETCONFIRMREQUEST']._serialized_start=646
  _globals['_QUERYVALSETCONFIRMREQUEST']._serialized_end=721
  _globals['_QUERYVALSETCONFIRMRESPONSE']._serialized_start=723
  _globals['_QUERYVALSETCONFIRMRESPONSE']._serialized_end=815
  _globals['_QUERYVALSETCONFIRMSBYNONCEREQUEST']._serialized_start=817
  _globals['_QUERYVALSETCONFIRMSBYNONCEREQUEST']._serialized_end=874
  _globals['_QUERYVALSETCONFIRMSBYNONCERESPONSE']._serialized_start=876
  _globals['_QUERYVALSETCONFIRMSBYNONCERESPONSE']._serialized_end=978
  _globals['_QUERYLASTVALSETREQUESTSREQUEST']._serialized_start=980
  _globals['_QUERYLASTVALSETREQUESTSREQUEST']._serialized_end=1012
  _globals['_QUERYLASTVALSETREQUESTSRESPONSE']._serialized_start=1014
  _globals['_QUERYLASTVALSETREQUESTSRESPONSE']._serialized_end=1101
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST']._serialized_start=1103
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST']._serialized_end=1173
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE']._serialized_start=1175
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE']._serialized_end=1274
  _globals['_QUERYBATCHFEEREQUEST']._serialized_start=1276
  _globals['_QUERYBATCHFEEREQUEST']._serialized_end=1298
  _globals['_QUERYBATCHFEERESPONSE']._serialized_start=1300
  _globals['_QUERYBATCHFEERESPONSE']._serialized_end=1384
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST']._serialized_start=1386
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST']._serialized_end=1455
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE']._serialized_start=1457
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE']._serialized_end=1560
  _globals['_QUERYOUTGOINGTXBATCHESREQUEST']._serialized_start=1562
  _globals['_QUERYOUTGOINGTXBATCHESREQUEST']._serialized_end=1593
  _globals['_QUERYOUTGOINGTXBATCHESRESPONSE']._serialized_start=1595
  _globals['_QUERYOUTGOINGTXBATCHESRESPONSE']._serialized_end=1690
  _globals['_QUERYBATCHREQUESTBYNONCEREQUEST']._serialized_start=1692
  _globals['_QUERYBATCHREQUESTBYNONCEREQUEST']._serialized_end=1790
  _globals['_QUERYBATCHREQUESTBYNONCERESPONSE']._serialized_start=1792
  _globals['_QUERYBATCHREQUESTBYNONCERESPONSE']._serialized_end=1885
  _globals['_QUERYBATCHCONFIRMSREQUEST']._serialized_start=1887
  _globals['_QUERYBATCHCONFIRMSREQUEST']._serialized_end=1979
  _globals['_QUERYBATCHCONFIRMSRESPONSE']._serialized_start=1981
  _globals['_QUERYBATCHCONFIRMSRESPONSE']._serialized_end=2074
  _globals['_QUERYLASTEVENTBYADDRREQUEST']._serialized_start=2076
  _globals['_QUERYLASTEVENTBYADDRREQUEST']._serialized_end=2131
  _globals['_QUERYLASTEVENTBYADDRRESPONSE']._serialized_start=2133
  _globals['_QUERYLASTEVENTBYADDRRESPONSE']._serialized_end=2241
  _globals['_QUERYERC20TODENOMREQUEST']._serialized_start=2243
  _globals['_QUERYERC20TODENOMREQUEST']._serialized_end=2291
  _globals['_QUERYERC20TODENOMRESPONSE']._serialized_start=2293
  _globals['_QUERYERC20TODENOMRESPONSE']._serialized_end=2387
  _globals['_QUERYDENOMTOERC20REQUEST']._serialized_start=2389
  _globals['_QUERYDENOMTOERC20REQUEST']._serialized_end=2437
  _globals['_QUERYDENOMTOERC20RESPONSE']._serialized_start=2439
  _globals['_QUERYDENOMTOERC20RESPONSE']._serialized_end=2533
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESS']._serialized_start=2535
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESS']._serialized_end=2617
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE']._serialized_start=2620
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE']._serialized_end=2749
  _globals['_QUERYDELEGATEKEYSBYETHADDRESS']._serialized_start=2751
  _globals['_QUERYDELEGATEKEYSBYETHADDRESS']._serialized_end=2815
  _globals['_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE']._serialized_start=2818
  _globals['_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE']._serialized_end=2953
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS']._serialized_start=2955
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS']._serialized_end=3046
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE']._serialized_start=3048
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE']._serialized_end=3174
  _globals['_QUERYPENDINGSENDTOETH']._serialized_start=3176
  _globals['_QUERYPENDINGSENDTOETH']._serialized_end=3238
  _globals['_QUERYPENDINGSENDTOETHRESPONSE']._serialized_start=3241
  _globals['_QUERYPENDINGSENDTOETHRESPONSE']._serialized_end=3451
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=3453
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=3478
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=3480
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=3562
  _globals['_MISSINGNONCESREQUEST']._serialized_start=3564
  _globals['_MISSINGNONCESREQUEST']._serialized_end=3586
  _globals['_MISSINGNONCESRESPONSE']._serialized_start=3588
  _globals['_MISSINGNONCESRESPONSE']._serialized_end=3658
  _globals['_QUERY']._serialized_start=3661
  _globals['_QUERY']._serialized_end=7059
# @@protoc_insertion_point(module_scope)
